package com.ruoyi.branch.service;

import java.util.List;
import com.ruoyi.branch.domain.TBranchPlan;

/**
 * 支部年度工作计划Service接口
 * 
 * @author ruoyi
 * @date 2023-07-17
 */
public interface ITBranchPlanService 
{
    /**
     * 查询支部年度工作计划
     * 
     * @param planId 支部年度工作计划主键
     * @return 支部年度工作计划
     */
    public TBranchPlan selectTBranchPlanByPlanId(Long planId);

    /**
     * 查询支部年度工作计划列表
     * 
     * @param tBranchPlan 支部年度工作计划
     * @return 支部年度工作计划集合
     */
    public List<TBranchPlan> selectTBranchPlanList(TBranchPlan tBranchPlan);

    /**
     * 新增支部年度工作计划
     * 
     * @param tBranchPlan 支部年度工作计划
     * @return 结果
     */
    public int insertTBranchPlan(TBranchPlan tBranchPlan);

    /**
     * 修改支部年度工作计划
     * 
     * @param tBranchPlan 支部年度工作计划
     * @return 结果
     */
    public int updateTBranchPlan(TBranchPlan tBranchPlan);

    /**
     * 批量删除支部年度工作计划
     * 
     * @param planIds 需要删除的支部年度工作计划主键集合
     * @return 结果
     */
    public int deleteTBranchPlanByPlanIds(Long[] planIds);

    /**
     * 删除支部年度工作计划信息
     * 
     * @param planId 支部年度工作计划主键
     * @return 结果
     */
    public int deleteTBranchPlanByPlanId(Long planId);
}
